import os
import argparse
from .image_knock import search_corrputed_imgs

class bcolors:
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKCYAN = '\033[96m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'
    BOLD = '\033[1m'
    UNDERLINE = '\033[4m'

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--path", type=str, default="./", help="Dataset Path")
    parser.add_argument("--exts", 
                        type=str, 
                        action="store",
                        nargs="+",
                        default=["jpg",
                                 "png",
                                 "jpeg",
                                 "bmp",
                                 "tif",
                                 "tiff"],
                        help="Image File Extension List")
    parser.add_argument("--output-path", type=str, default="./", help="Where to save corrupted image file list")
    parser.add_argument('--nosave', action='store_true', help='Only print corrupted image file list without saving file')
    args = parser.parse_args()
    
    assert os.path.isdir(args.path)
    
    print(bcolors.OKGREEN + f"Knocking... Root Path: {os.path.abspath(args.output_path)}" + bcolors.ENDC)
    
    corrupted_imgs = search_corrputed_imgs(path=args.path,
                                           exts=args.exts)
  
    if len(corrupted_imgs) == 0:
        print(bcolors.OKGREEN + "There are no corrupted image files! All images were loaded successfully using PIL.Image.open!" + bcolors.ENDC)
    else:
        corrupted_imgs = "\n".join(corrupted_imgs)
        
        print(bcolors.FAIL + "Corrupted image files are detected!" + bcolors.ENDC)
        print(bcolors.WARNING + corrupted_imgs + bcolors.ENDC)
        
        output = os.path.join(os.path.abspath(args.output_path), "corrupted_imgs_list.txt")
        
        if args.nosave == False:
            print(f"Corrupted image file list is saved to {output}")
            with open(output, mode="w", encoding="UTF-8") as f:
                f.write(corrupted_imgs + "\n")

if __name__ == "__main__":
    main()


from PIL import Image
import tqdm
from itertools import compress
import os
import multiprocessing

def is_corrupted_img(file):
    try:
        img = Image.open(file)
        img.verify()
        return img is None
    except:
        return True

def read_files(path, exts):
    files = []
    for r, d, f in os.walk(path):
        for file in f:
            if file.lower().endswith(exts):
                file = os.path.join(r, file)
                file = os.path.abspath(file)
                file = file.replace(os.sep, "/")
                files.append(file)
    return files

def search_corrputed_imgs(path,
                          exts=("jpg",
                                "png",
                                "jpeg",
                                "bmp",
                                "tif",
                                "tiff")
                          ):
    exts = tuple(exts)
    imgs = read_files(path, exts)
    corrupted_imgs = []
    if len(imgs) > 0:
        with multiprocessing.Pool() as p:
            is_corrupted = list(tqdm.tqdm(p.imap(is_corrupted_img, imgs), total=len(imgs)))
            corrupted_imgs = list(compress(imgs, is_corrupted))
    return corrupted_imgs
        


import setuptools
import re

with open("image_knocker/__init__.py", "r") as f:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
        f.read(), re.MULTILINE
    ).group(1)

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

def get_requires(filename):
    requirements = []
    with open(filename, "rt") as req_file:
        for line in req_file.read().splitlines():
            if not line.strip().startswith("#"):
                requirements.append(line)
    return requirements

project_requirements = get_requires("./requirements.txt")

setuptools.setup(
    name="image_knocker",
    version=version,
    license='Apache',
    python_requires=">=3.6",
    author="Yonghye Kwon",
    author_email="developer.0hye@gmail.com",
    description="Knock your images before these make you painful",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/developer0hye/image-knocker",
    packages=setuptools.find_packages(),
    install_requires=project_requirements,
    zip_safe=False,
    keywords=['image', 'img'],
    entry_points={
        'console_scripts': ['image-knocker=image_knocker.image_knocker:main']
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)